/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common.command;

import java.util.Map;

import org.apache.commons.collections.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.MappingConstants;
import org.mapstruct.ValueMapping;
import org.springframework.beans.factory.annotation.Autowired;

import de.ozgcloud.alfa.common.TimeMapper;
import de.ozgcloud.alfa.common.callcontext.CallContextMapper;
import de.ozgcloud.alfa.common.user.UserIdMapper;
import de.ozgcloud.alfa.forwarding.RedirectRequest;
import de.ozgcloud.vorgang.common.grpc.GrpcObjectMapper;
import de.ozgcloud.vorgang.grpc.command.GrpcCommand;
import de.ozgcloud.vorgang.grpc.command.GrpcRedirectRequest;

@Mapper(uses = { CallContextMapper.class, TimeMapper.class, CommandBodyMapper.class, GrpcObjectMapper.class, UserIdMapper.class })
public abstract class CommandMapper {

	@Autowired
	private GrpcObjectMapper objectMapper;
	@Autowired
	private CommandBodyMapper bodyMapper;

	@ValueMapping(source = "UNRECOGNIZED", target = MappingConstants.NULL)
	@ValueMapping(source = "UNDEFINED", target = MappingConstants.NULL)
	@Mapping(source = "orderString", target = "order")
	@Mapping(target = "body", expression = "java(mapBody(grpcCommand))")
	abstract Command toCommand(GrpcCommand grpcCommand);

	RedirectRequest mapRedirectRequest(GrpcRedirectRequest request) {
		var builder = RedirectRequest.builder().email(request.getEmail());
		if (StringUtils.isNotEmpty(request.getPassword())) {
			builder.password(request.getPassword().toCharArray());
		}
		return builder.build();
	}

	Map<String, ?> mapBody(GrpcCommand command) {
		var bodyObject = objectMapper.mapFromGrpc(command.getBodyObj());

		if (MapUtils.isNotEmpty(bodyObject)) {
			return bodyObject;
		} else {
			return bodyMapper.map(command.getBody());
		}
	}

	String mapStringtoNull(String in) {
		return StringUtils.trimToNull(in);
	}
}