/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.aktenzeichen;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.EnumSource;
import org.mockito.InjectMocks;
import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.Link;
import org.springframework.hateoas.UriTemplate;

import de.ozgcloud.alfa.common.command.CommandController;
import de.ozgcloud.alfa.vorgang.Vorgang;
import de.ozgcloud.alfa.vorgang.VorgangHeaderTestFactory;
import de.ozgcloud.alfa.vorgang.VorgangWithEingang;
import de.ozgcloud.alfa.vorgang.VorgangWithEingangTestFactory;

class AktenzeichenModelProcessorTest {

	@InjectMocks
	private AktenzeichenModelProcessor processor;

	@Nested
	class TestSetAktenzeichenLink {

		@DisplayName("should not add a link if Vorgang is not present")
		@Test
		void shouldDoNothing() {
			var model = processor.process(mock(EntityModel.class));

			assertThat(model.hasLinks()).isFalse();
		}

		@ParameterizedTest
		@EnumSource(names = { "ANGENOMMEN", "IN_BEARBEITUNG" }, mode = EnumSource.Mode.EXCLUDE)
		void shouldNotCreateSetAktenzeichenLink(Vorgang.VorgangStatus vorgangStatus) {
			var model = processor.process(buildModelWithVorgangStatus(vorgangStatus));

			assertThat(model.getLink(AktenzeichenModelProcessor.REL_SET_AKTENZEICHEN)).isEmpty();
		}

		@ParameterizedTest
		@EnumSource(names = { "ANGENOMMEN", "IN_BEARBEITUNG" })
		void shouldCreateSetAktenzeichenLink(Vorgang.VorgangStatus vorgangStatus) {
			var model = processor.process(buildModelWithVorgangStatus(vorgangStatus));

			assertThat(model.getLink(AktenzeichenModelProcessor.REL_SET_AKTENZEICHEN)).isPresent().get()
					.extracting(Link::getHref)
					.isEqualTo(UriTemplate.of(CommandController.CommandByRelationController.COMMAND_BY_RELATION_PATH)
							.expand(VorgangHeaderTestFactory.ID, VorgangHeaderTestFactory.ID, VorgangHeaderTestFactory.VERSION).toString());
		}
	}

	private EntityModel<VorgangWithEingang> buildModelWithVorgangStatus(Vorgang.VorgangStatus vorgangStatus) {
		return EntityModel.of(VorgangWithEingangTestFactory.createBuilder().status(vorgangStatus).build());
	}
}
