/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.bescheid;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.alfa.common.binaryfile.FileIdMapper;

public class DocumentMapperTest {

	@Mock
	private FileIdMapper fileIdMapper;
	@InjectMocks
	private final DocumentMapper mapper = Mappers.getMapper(DocumentMapper.class);

	@Nested
	class TestFromGrpc {

		@BeforeEach
		void init() {
			when(fileIdMapper.toFileId(GrpcDocumentTestFactory.FILE_ID)).thenReturn(DocumentTestFactory.FILE_ID);
		}

		@Test
		void shouldMapId() {
			var document = map();

			assertThat(document.getId()).isEqualTo(GrpcDocumentTestFactory.ID);
		}

		@Test
		void shouldMapType() {
			var document = map();

			assertThat(document.getType()).isEqualTo(GrpcDocumentTestFactory.TYPE);
		}

		@Test
		void shouldMapFileId() {
			var document = map();

			assertThat(document.getFileId()).isEqualTo(DocumentTestFactory.FILE_ID);
		}

		@Test
		void shouldMapNachrichtSubject() {
			var document = map();

			assertThat(document.getNachrichtSubject()).isEqualTo(GrpcDocumentTestFactory.NACHRICHT_SUBJECT);
		}

		@Test
		void shouldMapNachrichtText() {
			var document = map();

			assertThat(document.getNachrichtText()).isEqualTo(GrpcDocumentTestFactory.NACHRICHT_TEXT);
		}

		private Document map() {
			return mapper.fromGrpc(GrpcDocumentTestFactory.create());
		}
	}
}
