/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.collaboration;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcAnschrift;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcOrganisationsEinheit;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcOrganisationsEinheit.Builder;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcXzufiId;
import de.ozgcloud.zufi.grpc.organisationseinheit.GrpcZustaendigkeit;

public class GrpcOrganisationsEinheitTestFactory {
	public static final String ID = OrganisationsEinheitTestFactory.ID;
	public static final GrpcXzufiId XZUFI_ID = GrpcXzufiIdTestFactory.create();
	public static final String NAME = OrganisationsEinheitTestFactory.NAME;
	public static final String SYNONYME = LoremIpsum.getInstance().getWords(5);
	public static final String VORGANG_MANAGER_ADDRESS = LoremIpsum.getInstance().getUrl();
	public static final GrpcAnschrift ANSCHRIFT = GrpcAnschriftTestFactory.create();
	public static final GrpcZustaendigkeit ZUSTAENDIGKEIT = GrpcZustaendigkeitTestFactory.create();

	public static GrpcOrganisationsEinheit create() {
		return createBuilder().build();
	}

	public static GrpcOrganisationsEinheit createWithoutSynonyme() {
		return createBuilderWithoutSynonyme()
				.build();
	}

	public static Builder createBuilder() {
		return createBuilderWithoutSynonyme()
				.setSynonyme(SYNONYME);
	}

	public static Builder createBuilderWithoutSynonyme() {
		return GrpcOrganisationsEinheit.newBuilder()
				.setId(ID)
				.setName(NAME)
				.setAnschrift(ANSCHRIFT)
				.setVorgangManagerAddress(VORGANG_MANAGER_ADDRESS)
				.addZustaendigkeiten(ZUSTAENDIGKEIT)
				.setXzufiId(XZUFI_ID);
	}

}
