/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.web.servlet.assertj.MockMvcTester;
import org.springframework.test.web.servlet.assertj.MvcTestResult;
import org.springframework.web.context.WebApplicationContext;

import de.ozgcloud.common.test.ITCase;
import lombok.SneakyThrows;

@ITCase
class LinkedResourceProcessorITCase {

	@Autowired
	private WebApplicationContext context;
	private MockMvcTester mockMvc;

	@BeforeEach
	void setup() {
		this.mockMvc = MockMvcTester.from(this.context);
	}

	@Test
	@SneakyThrows
	void shouldHaveAddLinkByLinkedResource() {
		var result = doRequest();

		result.assertThat().bodyJson().extractingPath("$._links.linkedResource.href")
				.isEqualTo("http://localhost" + TestIdController.PATH + "/" + TestEntityTestFactory.LINKED_RESOURCE);
	}

	@Test
	@SneakyThrows
	void shouldHaveUserProfileLink() {
		var result = doRequest();

		result.assertThat().bodyJson().extractingPath("$._links.user.href")
				.isEqualTo("https://localhost/api/userProfiles/" + TestEntityTestFactory.USER);
	}

	private MvcTestResult doRequest() {
		return mockMvc.get().uri(TestEntityController.PATH).exchange();
	}
}
